import ssl
import threading

import aiohttp


class AiohttpSingleton:
    """aiohttp session for each uvicorn worker"""
    _session = None
    _lock = threading.Lock()

    @classmethod
    async def session(cls) -> aiohttp.ClientSession:
        if not cls._session:
            with cls._lock:
                # Another thread could have created the instance before we acquired the
                # lock. So check that the instance is still nonexistent.
                if not cls._session:
                    context = ssl._create_unverified_context()
                    connector = aiohttp.TCPConnector(ssl=context)
                    cls._session = aiohttp.ClientSession(connector=connector)
        return cls._session
