import sys

from cachetools import TTLCache
from fastapi import FastAPI
from fastapi.responses import RedirectResponse

from .client import AiohttpSingleton
from .config import CACHE_TTL_SECONDS
from .routers.simple import simple_router

app = FastAPI(
    title="acc-py-pi grouping service",
    version="0.0.1",
)
app.state.cache = TTLCache(sys.maxsize, CACHE_TTL_SECONDS)
app.include_router(simple_router)


@app.on_event("shutdown")
async def shutdown():
    session = await AiohttpSingleton.session()
    await session.close()


@app.get("/")
async def redirect_to_docs():
    return RedirectResponse("/docs", 307)
